// Copyright 2023 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

syntax = "proto3";

package google.ads.googleads.v16.resources;

import "google/ads/googleads/v16/enums/asset_set_link_status.proto";
import "google/api/field_behavior.proto";
import "google/api/resource.proto";

option csharp_namespace = "Google.Ads.GoogleAds.V16.Resources";
option go_package = "google.golang.org/genproto/googleapis/ads/googleads/v16/resources;resources";
option java_multiple_files = true;
option java_outer_classname = "AdGroupAssetSetProto";
option java_package = "com.google.ads.googleads.v16.resources";
option objc_class_prefix = "GAA";
option php_namespace = "Google\\Ads\\GoogleAds\\V16\\Resources";
option ruby_package = "Google::Ads::GoogleAds::V16::Resources";

// Proto file describing the AdGroupAssetSet resource.

// AdGroupAssetSet is the linkage between an ad group and an asset set.
// Creating an AdGroupAssetSet links an asset set with an ad group.
message AdGroupAssetSet {
  option (google.api.resource) = {
    type: "googleads.googleapis.com/AdGroupAssetSet"
    pattern: "customers/{customer_id}/adGroupAssetSets/{ad_group_id}~{asset_set_id}"
  };

  // Immutable. The resource name of the ad group asset set.
  // Ad group asset set resource names have the form:
  //
  // `customers/{customer_id}/adGroupAssetSets/{ad_group_id}~{asset_set_id}`
  string resource_name = 1 [
    (google.api.field_behavior) = IMMUTABLE,
    (google.api.resource_reference) = {
      type: "googleads.googleapis.com/AdGroupAssetSet"
    }
  ];

  // Immutable. The ad group to which this asset set is linked.
  string ad_group = 2 [
    (google.api.field_behavior) = IMMUTABLE,
    (google.api.resource_reference) = {
      type: "googleads.googleapis.com/AdGroup"
    }
  ];

  // Immutable. The asset set which is linked to the ad group.
  string asset_set = 3 [
    (google.api.field_behavior) = IMMUTABLE,
    (google.api.resource_reference) = {
      type: "googleads.googleapis.com/AssetSet"
    }
  ];

  // Output only. The status of the ad group asset set. Read-only.
  google.ads.googleads.v16.enums.AssetSetLinkStatusEnum.AssetSetLinkStatus
      status = 4 [(google.api.field_behavior) = OUTPUT_ONLY];
}
